==> simgrid_3.21%2Bdfsg.orig.tar.xz: SimGrid-3.21/README.md <==
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![Travis Status](https://travis-ci.org/simgrid/simgrid.svg?branch=master)](https://travis-ci.org/simgrid/simgrid)
[![AppVeyor Status](https://ci.appveyor.com/api/projects/status/gvcssh340fwtoc35?svg=true)](https://ci.appveyor.com/project/mquinson/simgrid)
[![SonarCloud Status](https://sonarcloud.io/api/project_badges/measure?project=simgrid&metric=alert_status)](https://sonarcloud.io/dashboard/?id=simgrid)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/bf1bdba50440485fbda2ac19f462ccc7)](https://www.codacy.com/app/mquinson/simgrid?utm_source=github.com&amp)
[![Doc](https://readthedocs.org/projects/pip/badge/?version=stable)](http://simgrid.gforge.inria.fr/simgrid/latest/doc/)
[![License: LGPL v3][license-badge]](COPYING)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1845/badge)](https://bestpractices.coreinfrastructure.org/projects/1845)

# Welcome to the SimGrid project!

SimGrid is a scientific instrument to study the behavior of 
large-scale distributed systems such as Grids, Clouds, HPC or P2P
systems. It can be used to evaluate heuristics, prototype applications 
or even assess legacy MPI applications.

More documentation is included in this archive (doc/html/index.html)
or [online](http://simgrid.gforge.inria.fr/)

In any case, you may want to subscribe to the [user mailing list](http://lists.gforge.inria.fr/mailman/listinfo/simgrid-user). 
There, you can find answers to your questions, or simply discuss with
people doing the same kind of research than you do, in an active and
friendly community.

Thanks for using our software. Please do great things with it and tell
the world about it. Tell us, too, because we love to have positive
feedback.

Cheers,
Da SimGrid Team.

[license-badge]: https://img.shields.io/badge/License-LGPL%20v3-blue.svg
[release-badge]: https://img.shields.io/github/release/simgrid/simgrid.svg
[release-link]:  https://gforge.inria.fr/frs/?group_id=12

==> simgrid_3.22%2Bdfsg.orig.tar.xz: SimGrid-3.22/README.md <==
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
[![Travis Status](https://img.shields.io/travis/simgrid/simgrid/master.svg?logo=travis)](https://travis-ci.org/simgrid/simgrid)
[![AppVeyor Status](https://ci.appveyor.com/api/projects/status/gvcssh340fwtoc35?svg=true)](https://ci.appveyor.com/project/mquinson/simgrid)
[![SonarCloud Status](https://sonarcloud.io/api/project_badges/measure?project=simgrid&metric=alert_status)](https://sonarcloud.io/dashboard/?id=simgrid)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/bf1bdba50440485fbda2ac19f462ccc7)](https://www.codacy.com/app/mquinson/simgrid?utm_source=github.com&amp)
[![Doc](https://readthedocs.org/projects/pip/badge/?version=stable)](http://simgrid.gforge.inria.fr/simgrid/latest/doc/)
[![License: LGPL v3][license-badge]](COPYING)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/1845/badge)](https://bestpractices.coreinfrastructure.org/projects/1845)

# Welcome to the SimGrid project!

SimGrid is a scientific instrument to study the behavior of 
large-scale distributed systems such as Grids, Clouds, HPC or P2P
systems. It can be used to evaluate heuristics, prototype applications 
or even assess legacy MPI applications.

More documentation is included in this archive (doc/html/index.html)
or [online](https://simgrid.org/)

In any case, you may want to subscribe to the [user mailing list](http://lists.gforge.inria.fr/mailman/listinfo/simgrid-user). 
There, you can find answers to your questions, or simply discuss with
people doing the same kind of research than you do, in an active and
friendly community.

Thanks for using our software. Please do great things with it and tell
the world about it. Tell us, too, because we love to have positive
feedback.

Cheers,
Da SimGrid Team.

[license-badge]: https://img.shields.io/badge/License-LGPL%20v3-blue.svg
[release-badge]: https://img.shields.io/github/release/simgrid/simgrid.svg
[release-link]:  https://gforge.inria.fr/frs/?group_id=12
